# -*- coding: utf-8 -*-
# ---
# jupyter:
#   jupytext:
#     text_representation:
#       extension: .py
#       format_name: light
#       format_version: '1.5'
#       jupytext_version: 1.13.1
#   kernelspec:
#     display_name: Python 3 (ipykernel)
#     language: python
#     name: python3
# ---

# +
import os
import csv
import datetime
import time

def filenameGet():
    csv_list = []; text_list =[]
    for filename in os.listdir('./'):
        if filename.startswith('dx-5_'):
            if filename.endswith('.csv'):
                csv_list.append(filename[:-4])
            elif filename == 'dx-5_settings.txt':
                text_list.append(filename)
            
    return csv_list, text_list

def fileProcess(csv_list, text_list, timenow):
    columnname_label = ''; data_label = ''
    for text in text_list:
        with open(f'./{text}') as f_in:
            for row in f_in:
                if '列名:' in row:
                    columnname_label = row.split(':')[1].replace('\n','')
                if 'データ:' in row:
                    data_label = row.split(':')[1].replace('\n','')
    
    if columnname_label == '':
        print('列名ラベルの文字列がありません。')
        print('dx-5_settings.txtの「列名:」に列名ラベルを記入してください。')
        print('処理を中止します。')
        
    if data_label == '':
        print('データラベルの文字列がありません。')
        print('dx-5_settings.txtの「データ:」にデータラベルを記入してください。')
        print('処理を中止します。')
    else: 
        print(f'列名:{columnname_label}、データ:{data_label}でデータの取得を開始します')

        for csv in csv_list:
            settings_data = []; value_data = []
            print(f'{csv}を処理します。')
            with open(f'./{csv}.csv', 'r') as f_in:
                for row in f_in:
                    if data_label == row.split(',')[0] or columnname_label == row.split(',')[0]:
                        data = ''
                        for value in row.split(',')[1:]:
                            data = data + value + ','
                            
                        value_data.append(data.rstrip(','))

                    else:
                        settings_data.append(row)

            with open(f'{timenow}_{csv}.txt', 'w') as f_out:
                for row in settings_data:
                    f_out.write(row)

            print(f'{csv}の設定データを{timenow}_{csv}.txtに保存しました。')

            with open(f'{timenow}_{csv}.csv', 'w') as f_out:
                for row in value_data:
                    f_out.write(row)

            print(f'{csv}のデータを{timenow}_{csv}.csvに保存しました。')


# +
def main():
    timenow = timenow = datetime.datetime.now().strftime("%Y%m%d%H%M%S")

    csv_list, text_list = filenameGet()
    print(f'CSVファイル：{csv_list}')
    print(f'TEXTファイル：{text_list}')
    
    fileProcess(csv_list, text_list, timenow)
    
    print('このウインドウは10秒後に自動で閉じますので、そのままお待ちください。')
    time.sleep(10)
    
if __name__ == '__main__':
    main()
# -






